@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FAKE_AKONADI_SERVER_COMMAND_H
-#define FAKE_AKONADI_SERVER_COMMAND_H
+#pragma once
 
 #include <QString>
 
@@ -22,7 +21,12 @@ class AKONADITESTFAKE_EXPORT FakeAkonadiServerCommand : public QObject
 {
     Q_OBJECT
 public:
-    enum Type { Notification, RespondToCollectionFetch, RespondToItemFetch, RespondToTagFetch };
+    enum Type {
+        Notification,
+        RespondToCollectionFetch,
+        RespondToItemFetch,
+        RespondToTagFetch,
+    };
 
     FakeAkonadiServerCommand(Type type, FakeServerData *serverData);
 
@@ -330,7 +334,10 @@ class AKONADITESTFAKE_EXPORT FakeJobResponse : public FakeAkonadiServerCommand
 {
     Q_OBJECT
     struct Token {
-        enum Type { Branch, Leaf };
+        enum Type {
+            Branch,
+            Leaf,
+        };
         Type type;
         QString content;
     };
@@ -380,4 +387,3 @@ private:
                                   int depth);
 };
 
-#endif
