@@ -8,23 +8,23 @@
 #include "knutresource.h"
 #include "knutresource_debug.h"
 #include "settingsadaptor.h"
-#include "xmlwriter.h"
 #include "xmlreader.h"
+#include "xmlwriter.h"
 
+#include <QDBusConnection>
 #include <agentfactory.h>
 #include <changerecorder.h>
-#include <QDBusConnection>
 #include <itemfetchscope.h>
 #include <tagcreatejob.h>
 
-#include <QFileDialog>
 #include <KLocalizedString>
+#include <QFileDialog>
 
+#include <QDir>
 #include <QFile>
 #include <QFileSystemWatcher>
-#include <QDir>
-#include <QUuid>
 #include <QStandardPaths>
+#include <QUuid>
 
 using namespace Akonadi;
 
@@ -37,8 +37,7 @@ KnutResource::KnutResource(const QString &id)
     changeRecorder()->fetchCollection(true);
 
     new SettingsAdaptor(mSettings);
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/Settings"),
-            mSettings, QDBusConnection::ExportAdaptors);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/Settings"), mSettings, QDBusConnection::ExportAdaptors);
     connect(this, &KnutResource::reloadConfiguration, this, &KnutResource::load);
     connect(mWatcher, &QFileSystemWatcher::fileChanged, this, &KnutResource::load);
     load();
@@ -99,10 +98,12 @@ void KnutResource::configure(WId windowId)
     }
 
     // TODO: Use windowId
-    Q_UNUSED(windowId);
-    const QString newFile = QFileDialog::getSaveFileName(
-        nullptr, i18n("Select Data File"), QString(),
-        QStringLiteral("*.xml |") + i18nc("Filedialog filter for Akonadi data file", "Akonadi Knut Data File"));
+    Q_UNUSED(windowId)
+    const QString newFile =
+        QFileDialog::getSaveFileName(nullptr,
+                                     i18n("Select Data File"),
+                                     QString(),
+                                     QStringLiteral("*.xml |") + i18nc("Filedialog filter for Akonadi data file", "Akonadi Knut Data File"));
 
     if (newFile.isEmpty() || oldFile == newFile) {
         return;
@@ -121,7 +122,7 @@ void KnutResource::retrieveCollections()
     collectionsRetrieved(collections);
     const Tag::List tags = mDocument.tags();
     Q_FOREACH (const Tag &tag, tags) {
-        TagCreateJob *createjob = new TagCreateJob(tag);
+        auto createjob = new TagCreateJob(tag);
         createjob->setMergeIfExisting(true);
     }
 }
@@ -140,7 +141,7 @@ void KnutResource::retrieveItems(const Akonadi::Collection &collection)
 #ifdef DO_IT_THE_OLD_WAY
 bool KnutResource::retrieveItem(const Item &item, const QSet<QByteArray> &parts)
 {
-    Q_UNUSED(parts);
+    Q_UNUSED(parts)
 
     const QDomElement itemElem = mDocument.itemElementByRemoteId(item.remoteId());
     if (itemElem.isNull()) {
@@ -157,7 +158,7 @@ bool KnutResource::retrieveItem(const Item &item, const QSet<QByteArray> &parts)
 
 bool KnutResource::retrieveItems(const Item::List &items, const QSet<QByteArray> &parts)
 {
-    Q_UNUSED(parts);
+    Q_UNUSED(parts)
 
     Item::List results;
     results.reserve(items.size());
@@ -219,7 +220,7 @@ void KnutResource::collectionChanged(const Akonadi::Collection &collection)
             continue;
         }
         if (child.tagName() == QLatin1String("item") || child.tagName() == QStringLiteral("collection")) {
-            newElem.appendChild(child);   // reparents
+            newElem.appendChild(child); // reparents
             --i; // children, despite being const is modified by the reparenting
         }
     }
@@ -246,7 +247,7 @@ void KnutResource::itemAdded(const Akonadi::Item &item, const Akonadi::Collectio
 {
     QDomElement parentElem = mDocument.collectionElementByRemoteId(collection.remoteId());
     if (parentElem.isNull()) {
-        Q_EMIT error(i18n("Parent collection '%1' not found in DOM tree." , collection.remoteId()));
+        Q_EMIT error(i18n("Parent collection '%1' not found in DOM tree.", collection.remoteId()));
         changeProcessed();
         return;
     }
@@ -264,7 +265,7 @@ void KnutResource::itemAdded(const Akonadi::Item &item, const Akonadi::Collectio
 
 void KnutResource::itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &parts)
 {
-    Q_UNUSED(parts);
+    Q_UNUSED(parts)
 
     const QDomElement oldElem = mDocument.itemElementByRemoteId(item.remoteId());
     if (oldElem.isNull()) {
@@ -345,7 +346,7 @@ QSet<qint64> KnutResource::parseQuery(const QString &queryString)
 
 void KnutResource::search(const QString &query, const Collection &collection)
 {
-    Q_UNUSED(collection);
+    Q_UNUSED(collection)
     const QVector<qint64> result = parseQuery(query).values().toVector();
     qCDebug(KNUTRESOURCE_LOG) << "KNUT QUERY:" << query;
     qCDebug(KNUTRESOURCE_LOG) << "KNUT RESOURCE:" << result;
@@ -354,16 +355,15 @@ void KnutResource::search(const QString &query, const Collection &collection)
 
 void KnutResource::addSearch(const QString &query, const QString &queryLanguage, const Collection &resultCollection)
 {
-    Q_UNUSED(query);
-    Q_UNUSED(queryLanguage);
-    Q_UNUSED(resultCollection);
-    qCDebug(KNUTRESOURCE_LOG) << "addSearch: query=" << query << ", queryLanguage="
-                              << queryLanguage << ", resultCollection=" << resultCollection.id();
+    Q_UNUSED(query)
+    Q_UNUSED(queryLanguage)
+    Q_UNUSED(resultCollection)
+    qCDebug(KNUTRESOURCE_LOG) << "addSearch: query=" << query << ", queryLanguage=" << queryLanguage << ", resultCollection=" << resultCollection.id();
 }
 
 void KnutResource::removeSearch(const Collection &resultCollection)
 {
-    Q_UNUSED(resultCollection);
+    Q_UNUSED(resultCollection)
     qCDebug(KNUTRESOURCE_LOG) << "removeSearch:" << resultCollection.id();
 }
 
