@@ -4,13 +4,12 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_AGENTMANAGER_H
-#define AKONADI_AGENTMANAGER_H
+#pragma once
 
 #include "akonadicore_export.h"
 
-#include "agenttype.h"
 #include "agentinstance.h"
+#include "agenttype.h"
 
 #include <QObject>
 
@@ -18,7 +17,6 @@
 
 namespace Akonadi
 {
-
 class AgentManagerPrivate;
 class Collection;
 
@@ -187,13 +185,12 @@ Q_SIGNALS:
     void instanceOnline(const Akonadi::AgentInstance &instance, bool online);
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     explicit AgentManager();
 
     std::unique_ptr<AgentManagerPrivate> const d;
-    //@endcond
+    /// @endcond
 };
 
 }
 
-#endif
