@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_RECURSIVEITEMFETCHJOB_H
-#define AKONADI_RECURSIVEITEMFETCHJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "item.h"
@@ -133,4 +132,3 @@ private:
 
 }
 
-#endif
