@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef AKONADI_PROTOCOL_DATASTREAM_P_P_H
-#define AKONADI_PROTOCOL_DATASTREAM_P_P_H
+#pragma once
 
 #include <chrono>
 #include <type_traits>
@@ -326,4 +325,3 @@ inline Akonadi::Protocol::DataStream &operator>>(Akonadi::Protocol::DataStream &
     return stream;
 }
 
-#endif // AKONADI_PROTOCOL_DATASTREAM_P_P_H
