@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef AKONADISERVER_H
-#define AKONADISERVER_H
+#pragma once
 
 #include <QObject>
 #include <QVector>
@@ -123,4 +122,3 @@ protected:
 
 } // namespace Server
 } // namespace Akonadi
-#endif
